<?php

require_once './auth.php';

call_user_func(function() {

    // Pega a origem da requisição
    $origin = isset($_SERVER['HTTP_ORIGIN'])? $_SERVER['HTTP_ORIGIN'] : '';

    // Uma lista de domínios permitidos
    $allowed_domains = [
        'https://neysoft.com.br',
        'https://casadabateria.com.br'
    ];

    // Verifica se a origem da requisição está na lista de domínios permitidos
    if (in_array($origin, $allowed_domains)) {
        // Seta os cabeçalhos de CORS
        header("Access-Control-Allow-Origin: $origin");
        header('Access-Control-Allow-Methods: GET, POST, PUT, DELETE');
        header('Access-Control-Allow-Credentials: true');
        header('Access-Control-Allow-Headers: Origin, Content-Type, X-Auth-Token, Authorization, Accept,charset,boundary,Content-Length');
    } else {
        // Define o código de status HTTP para "Unauthorized"
        http_response_code(401);
        
        // Envia uma mensagem de erro personalizada
        echo json_encode(['error' => 'Não autorizado, origem da requisição não permitida.']);
        exit;
    }


    // Verifica se a requisição é do método POST
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Verifica se o parâmetro 'private' está presente na requisição
        if (isset($_POST['private'])) {
            $jwt = $_POST['private'];
            requirePrivateApi($jwt);
        } else {
            $public = $_POST['public'];
            requirePublicApi($public);
        }
    }
});

function requirePublicApi($clientRequest)
{
    $client['client'] = $clientRequest['client'];
    $version['version'] = $clientRequest['version'];
    
    require_once __DIR__ . '/voicetec/clients/'.$client.'/'.$version.'/api.php';
    new apiVoicetec($clientRequest);
}

function requirePrivateApi($jwt)
{
    $client = new jwtVerifier($jwt);
    if ($client->jwtResponse()) {
        $request = $client->getClientRequest();
        require_once $client->file;
        new $client->class($request);
    }
}
